/* Use the following CSS code if you want to use data attributes for inserting your icons */
[data-icon]:before, [data-icon-after]:after {
  font-family: 'ST-Icons';
  speak: none;
  /* Enable Ligatures */
  -webkit-font-feature-settings: "liga", "dlig";
  -moz-font-feature-settings: "liga=1, dlig=1";
  -moz-font-feature-settings: "liga", "dlig";
  -ms-font-feature-settings: "liga", "dlig";
  font-feature-settings: "liga", "dlig";
  text-rendering: optimizeLegibility;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  content: attr(data-icon); }

[data-icon-after]:after {
  content: attr(data-icon-after); }

.st-icon {
  font-family: 'ST-Icons';
  speak: none;
  /* Enable Ligatures */
  -webkit-font-feature-settings: "liga", "dlig";
  -moz-font-feature-settings: "liga=1, dlig=1";
  -moz-font-feature-settings: "liga", "dlig";
  -ms-font-feature-settings: "liga", "dlig";
  font-feature-settings: "liga", "dlig";
  text-rendering: optimizeLegibility;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  cursor: pointer; }

[data-icon=bin]:hover:before {
  content: "binopen"; }

.st-block__inner ::-moz-selection {
  background: #34e0c2;
  text-shadow: none; }

.st-block__inner ::selection {
  background: #34e0c2;
  text-shadow: none; }

.st-spinner {
  position: absolute !important;
  left: 50%;
  top: 50%; }

.st-errors {
  background-color: #ffe1e4;
  padding: 2em;
  color: #d70014; }

.st-errors p, .st-errors ul {
  margin: 0; }

.st-errors ul {
  padding-left: 1em; }

.st-errors p {
  margin-bottom: 0.5em;
  font-weight: 700; }

.st--block-limit-reached .st-block-controls__top {
  display: none; }

.st-block-controls__top:before {
  width: 100%;
  display: block;
  text-align: center;
  font-size: 1.875em;
  padding: 0.3em 0;
  line-height: 0.9;
  border-radius: 0.2em; }

.st-block-controls__top:hover:before {
  color: #34e0c2;
  background: #f3f3f3; }

.st-block-controls {
  background-color: #f3f3f3;
  display: none;
  border-radius: 0.2em;
  color: #42474b;
  width: 100%;
  text-align: center;
  padding: 1.2em 0; }

.st-block-controls--active {
  display: block; }

.st-block-control {
  font-size: 1.125em;
  display: inline-block;
  cursor: pointer;
  margin: 0 1em 0 0; }

.st-block-control .st-icon {
  font-size: 2.25em;
  margin: 0 0 0.2em 0;
  display: block; }

.st-block-control:hover {
  color: #34e0c2; }

.st-block {
  padding: 0;
  position: relative; }

.st-block__inner {
  padding: 1.875em 1.875em 2.8em;
  border: 2px solid #fff;
  position: relative; }

.st-block__inner:hover {
  border-color: #34e0c2; }

.st-block--with-errors .st-block__inner, .st-block--delete-active .st-block__inner {
  border-color: #d70014; }

.st-block--with-plus:after, .st-icon--add:after {
  display: block;
  position: relative;
  z-index: 1;
  bottom: 0; }

.st--block-limit-reached .st-block--with-plus:after, .st--block-limit-reached .st-icon--add:after {
  display: none; }

.st-icon--add:after {
  text-align: center;
  font-size: 1.875em;
  padding: 0.3em 0;
  line-height: 0.9;
  border-radius: 0.2em; }

.st-block--with-plus:after {
  background: #f3f3f3;
  color: #34e0c2; }

.with-st-controls:after, .with-st-controls:before {
  display: none; }

.st-outer--is-reordering .st-block.st-drag-over:after, .st-outer--is-reordering .st-block.st-drag-over:last-child:after, .st-outer--is-reordering .st-block-controls__top.st-drag-over:before {
  font-family: inherit;
  content: "Drop block here";
  text-align: center;
  padding: 0.7em 0;
  font-size: 1.125em;
  font-weight: 700;
  border: 2px dashed #d4d4d4;
  background: transparent;
  color: #d4d4d4; }

.st-block__inputs {
  padding: 1.6em 0 1em;
  border-radius: 0.2em;
  background: #f3f3f3;
  border-top: 0.125em solid transparent; }

.st-block__dropzone .st-icon {
  font-size: 4em;
  color: #42474b;
  display: block;
  text-align: center;
  margin: 0 auto 0.2em; }

.st-block__dropzone p {
  text-align: center;
  color: #42474b;
  font-size: 1.2em;
  margin: 0; }

.st-block__dropzone p span {
  font-weight: 700; }

.st-drag-over .st-block__inputs {
  border-top-color: #cdcdcd; }

.st-block .st-block__paste-input[type="text"] {
  text-align: center;
  width: 80%;
  display: block;
  margin: 0.4em auto 0; }

.st-upload-btn {
  border: 0;
  background: #42474b;
  border-radius: 0.2em;
  padding: 0.35em 1em;
  font-size: 1.125em;
  cursor: pointer;
  color: #fff;
  position: relative;
  z-index: 10; }

.st-block__upload-container:hover .st-upload-btn {
  background: #34e0c2; }

.st-block__editor--with-sixteen-by-nine-media {
  padding-top: 56.25%;
  /* 16:9 */
  height: 0;
  position: relative;
  width: 100%; }

.st-block__editor--with-sixteen-by-nine-media video, .st-block__editor--with-sixteen-by-nine-media iframe {
  height: 100%;
  width: 100%;
  left: 0;
  top: 0;
  position: absolute; }

.st-block__editor img {
  width: 100%;
  height: auto; }

.st-block__upload-container {
  margin: 0.4em 0 0 0;
  text-align: center; }

.st-block__upload-container input[type="file"] {
  position: absolute;
  z-index: 50;
  opacity: 0;
  cursor: pointer;
  left: 0;
  width: 100%;
  padding: 7px 0;
  text-align: center; }

.st-block__messages {
  display: none;
  position: relative;
  top: -1.9em;
  left: -1.9em;
  padding: 0.3em 0.5em;
  border-left: none;
  border-top: none;
  max-width: 80%; }

.st-block__messages--is-visible {
  display: block; }

.st-block--with-errors .st-block__messages {
  border-color: #d70014; }

.st-block__messages span {
  display: block; }

.st-msg--error {
  color: #d70014; }

.st-block-positioner {
  border: 0.125em solid #34e0c2;
  position: absolute;
  z-index: 2;
  left: -5.5em;
  bottom: 0.4em;
  background: #fff;
  visibility: hidden;
  opacity: 0;
  transition: opacity 0.2s ease-in-out; }

.st-block-positioner--is-visible {
  visibility: visible;
  opacity: 1; }

.st-block-positioner:after {
  content: '';
  display: block;
  width: 0.4em;
  height: 0.4em;
  position: absolute;
  right: -0.3em;
  bottom: 0.6em;
  z-index: 1;
  border: 0.125em solid #34e0c2;
  background: #fff;
  -webkit-transform: rotate(45deg);
  transform: rotate(45deg); }

.st-block-positioner__title {
  color: #34e0c2;
  font-size: 0.7em;
  font-style: italic;
  font-weight: normal;
  margin: 0;
  border-bottom: 1px solid #34e0c2;
  padding: 0.5em;
  text-align: center; }

.st-block-positioner__inner {
  background: #fff;
  position: relative;
  z-index: 2;
  padding: 0.3em 0.5em; }

.st-block__ui, .st-block__ui-delete-controls {
  position: absolute;
  bottom: 0;
  right: 0;
  opacity: 0; }

.st-block__inner:hover .st-block__ui {
  opacity: 1; }

.st-block-ui-btn {
  display: block;
  float: left;
  width: 3em;
  height: 2.5em;
  line-height: 2.5em;
  font-size: 1.4em;
  color: #34e0c2;
  background: #fff;
  text-align: center;
  border: 2px solid #34e0c2;
  border-right: 0;
  border-bottom: 0;
  margin-bottom: 0;
  cursor: pointer; }

.st-block--with-errors .st-block-ui-btn, .st-block--delete-active .st-block-ui-btn {
  color: #d70014;
  border-color: #d70014; }

.st-block-ui-btn:hover {
  color: #fff;
  background: #34e0c2; }

.st-block--with-errors .st-block-ui-btn:hover, .st-block--delete-active .st-block-ui-btn:hover {
  background-color: #d70014; }

.st-block--delete-active .st-block__ui-delete-controls {
  opacity: 1;
  z-index: 2; }

.st-block__delete-label {
  display: block;
  float: none;
  width: auto;
  border: 2px solid #d70014;
  border-bottom: none;
  border-right: none;
  text-align: center;
  background: #fff;
  color: #d70014;
  padding: 0.4em 0; }

.st-format-bar {
  position: absolute;
  margin: -3em 0 0 0;
  background: #4d5358;
  opacity: 0;
  visibility: hidden;
  z-index: 10;
  border-radius: 0.4em;
  padding: 0.5em 0.9em;
  transition: opacity 0.2s ease-in-out; }

.st-format-bar:before {
  content: '';
  display: block;
  position: absolute;
  left: 50%;
  top: 2.12em;
  width: 0;
  height: 0;
  border-left: 0.625em solid transparent;
  border-right: 0.625em solid transparent;
  border-top: 0.625em solid #4d5358;
  margin-left: -0.625em; }

.st-format-bar--is-ready {
  visibility: visible;
  opacity: 1; }

.st-format-btn {
  background: transparent;
  border: 0;
  color: #fff;
  padding: 0 0.6em 0 0;
  margin: 0 0.6em 0 0;
  font-size: 1em;
  vertical-align: middle;
  border-right: 1px solid #3e4245; }

.st-format-btn:last-child {
  border-right: none;
  padding-right: 0;
  margin-right: 0; }

.st-format-btn:hover, .st-format-btn--is-active {
  color: #34e0c2; }

.st-format-btn--Italic {
  font-style: italic; }

.st-format-btn--Unlink {
  text-decoration: line-through; }

/*# sourceMappingURL=maps/sirtrevor.css.map */